{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Gene Set Characterization",
            "doc": "Network-guided gene set characterization method implementation by KnowEnG that relates public gene sets to user gene sets",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "knowengdev/geneset_characterization_pipeline:01_31_2017"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#gsc_runner.cwl/pg_network_file",
                    "label": "PG Network File",
                    "doc": "property-gene network of interactions in edge format",
                    "type": "File"
                },
                {
                    "id": "#gsc_runner.cwl/gg_network_file",
                    "label": "GG Network File",
                    "doc": "gene-gene network of interactions in edge format",
                    "type": "File"
                },
                {
                    "id": "#gsc_runner.cwl/genomic_file",
                    "label": "Genomic Spreadsheet File",
                    "doc": "spreadsheet of genomic data with samples as columns and genes as rows",
                    "type": "File"
                },
                {
                    "id": "#gsc_runner.cwl/gsc_method",
                    "label": "GSC Method",
                    "doc": "which method to use for GSC, i.e. DRaWR, fisher",
                    "type": "string"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "tail -n+2 $(inputs.genomic_file.path) |  awk '{print \\$1\\\"\\\\t\\\"\\$1}' > dummy.map &&\necho \"\nspreadsheet_name_full_path: $(inputs.genomic_file.path)\npg_network_name_full_path: $(inputs.pg_network_file.path)\ngene_names_map: dummy.map\nresults_directory: ./\nmethod: $(inputs.gsc_method)\ngg_network_name_full_path: $(inputs.pg_network_file.path)\nrwr_convergence_tolerence: 0.0001\nrwr_max_iterations: 500\nrwr_restart_probability: 0.5\n\" >> run_params.yml &&\npython3 /home/src/geneset_characterization.py -run_directory ./ -run_file run_params.yml"
                }
            ],
            "id": "#gsc_runner.cwl",
            "outputs": [
                {
                    "id": "#gsc_runner.cwl/enrichment_scores",
                    "label": "GSC Enrichment Scores",
                    "doc": "Edge format file with first three columns (user gene set, public gene set, score)",
                    "outputBinding": {
                        "glob": "*_sorted_by_property_score_*"
                    },
                    "type": "File"
                },
                {
                    "id": "#gsc_runner.cwl/params_yml",
                    "label": "Configuration Parameter File",
                    "doc": "contains the values used in analysis",
                    "outputBinding": {
                        "glob": "run_params.yml"
                    },
                    "type": "File"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Knowledge Network Fetcher",
            "doc": "Retrieve appropriate subnetwork from KnowEnG Knowledge Network from AWS S3 storage",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "cblatti3/aws:0.1"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#knf_runner.cwl/aws_access_key_id",
                    "label": "AWS Access Key ID",
                    "doc": "the aws access key id",
                    "type": "string",
                    "default": "AKIAIVLADKCGCVGHNLIA"
                },
                {
                    "id": "#knf_runner.cwl/aws_secret_access_key",
                    "label": "AWS Secret Access Key",
                    "doc": "the aws secrety access key",
                    "type": "string",
                    "default": "z1QYuHnp3IT9ajUrMXQo3ON0f4t4Uq58IjE0yLnJ"
                },
                {
                    "id": "#knf_runner.cwl/bucket",
                    "label": "AWS S3 Bucket Name",
                    "doc": "the aws s3 bucket",
                    "type": "string",
                    "default": "KnowNets/KN-6rep-1611/userKN-6rep-1611"
                },
                {
                    "id": "#knf_runner.cwl/network_type",
                    "label": "Subnetwork Class",
                    "doc": "the type of subnetwork",
                    "type": "string",
                    "default": "Gene"
                },
                {
                    "id": "#knf_runner.cwl/taxon",
                    "label": "Subnetwork Species ID",
                    "doc": "the taxonomic id for the species of interest",
                    "type": "string",
                    "default": "9606"
                },
                {
                    "id": "#knf_runner.cwl/edge_type",
                    "label": "Subnetwork Edge Type",
                    "doc": "the edge type keyword for the subnetwork of interest",
                    "type": "string",
                    "default": "PPI_physical_association"
                },
                {
                    "id": "#knf_runner.cwl/output_name",
                    "label": "Output Filename",
                    "doc": "the output file name to save the contents of the key to",
                    "type": "string",
                    "default": "KN.4col.edge"
                }
            ],
            "baseCommand": [
                "s3cmd"
            ],
            "arguments": [
                {
                    "prefix": "--access_key",
                    "valueFrom": "$(inputs.aws_access_key_id)"
                },
                {
                    "prefix": "--secret_key",
                    "valueFrom": "$(inputs.aws_secret_access_key)"
                },
                {
                    "valueFrom": "sync"
                },
                {
                    "valueFrom": "$('s3://' + inputs.bucket + '/' + inputs.network_type + '/' + inputs.taxon + '/' + inputs.edge_type + '/')"
                },
                {
                    "valueFrom": "./"
                }
            ],
            "outputs": [
                {
                    "id": "#knf_runner.cwl/output_file",
                    "label": "Subnetwork Edge File",
                    "doc": "4 column format for subnetwork for single edge type and species",
                    "outputBinding": {
                        "glob": "*.edge"
                    },
                    "type": "File"
                }
            ],
            "id": "#knf_runner.cwl"
        },
        {
            "class": "Workflow",
            "label": "GSC Paired Jobs",
            "doc": "Serial combination of KnowEnG tools",
            "inputs": [
                {
                    "id": "#main/pg_edge_type",
                    "label": "Subnetwork Edge Type",
                    "doc": "the edge type keyword for the subnetwork of interest",
                    "type": "string"
                },
                {
                    "id": "#main/taxon",
                    "label": "Subnetwork Species ID",
                    "doc": "the taxonomic id for the species of interest",
                    "type": "string",
                    "default": "9606"
                },
                {
                    "id": "#main/genomic_file",
                    "doc": "spreadsheet of genomic data with samples as columns and genes as rows",
                    "label": "Genomic Spreadsheet File",
                    "type": "File"
                },
                {
                    "id": "#main/gg_network_file",
                    "label": "GG Network File",
                    "doc": "gene-gene network of interactions in edge format",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "run": "#gsc_runner.cwl",
                    "in": [
                        {
                            "source": "#main/genomic_file",
                            "id": "#main/gsc_drawr/genomic_file"
                        },
                        {
                            "source": "#main/gg_network_file",
                            "id": "#main/gsc_drawr/gg_network_file"
                        },
                        {
                            "valueFrom": "DRaWR",
                            "id": "#main/gsc_drawr/gsc_method"
                        },
                        {
                            "source": "#main/pgkn_fetch/output_file",
                            "id": "#main/gsc_drawr/pg_network_file"
                        }
                    ],
                    "out": [
                        "#main/gsc_drawr/enrichment_scores"
                    ],
                    "id": "#main/gsc_drawr"
                },
                {
                    "run": "#knf_runner.cwl",
                    "in": [
                        {
                            "source": "#main/pg_edge_type",
                            "id": "#main/pgkn_fetch/edge_type"
                        },
                        {
                            "valueFrom": "Property",
                            "id": "#main/pgkn_fetch/network_type"
                        },
                        {
                            "valueFrom": "pg_knf_out",
                            "id": "#main/pgkn_fetch/output_name"
                        },
                        {
                            "source": "#main/taxon",
                            "id": "#main/pgkn_fetch/taxon"
                        }
                    ],
                    "out": [
                        "#main/pgkn_fetch/output_file"
                    ],
                    "id": "#main/pgkn_fetch"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/gsc_drawr/enrichment_scores",
                    "type": "File",
                    "id": "#main/gsc_drawr_out"
                },
                {
                    "outputSource": "#main/pgkn_fetch/output_file",
                    "type": "File",
                    "id": "#main/pgkn_fetch_out"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
